pub struct DelegationChainLink {
pub link_type: EntryType,
pub entry: Entry,
pub inclusion_proof: InclusionProof,
}Expand description
A single link in a delegation chain, containing the logged entry and its Merkle inclusion proof.
Each link proves that a delegation event (e.g., org member add) was recorded in the transparency log.
Args:
link_type— The type of delegation event this link represents.entry— The full log entry for the delegation event.inclusion_proof— Merkle proof that the entry is included in the log.
Usage:
ⓘ
let link = DelegationChainLink {
link_type: EntryType::OrgMemberAdd,
entry,
inclusion_proof: proof,
};Fields
link_type: EntryTypeentry: Entryinclusion_proof: InclusionProofTrait Implementations
Sourceimpl Clone for DelegationChainLink
impl Clone for DelegationChainLink
Sourcefn clone(&self) -> DelegationChainLink
fn clone(&self) -> DelegationChainLink
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DelegationChainLink
impl Debug for DelegationChainLink
Sourceimpl<'de> Deserialize<'de> for DelegationChainLink
impl<'de> Deserialize<'de> for DelegationChainLink
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DelegationChainLink
impl PartialEq for DelegationChainLink
Sourcefn eq(&self, other: &DelegationChainLink) -> bool
fn eq(&self, other: &DelegationChainLink) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DelegationChainLink
impl Serialize for DelegationChainLink
impl StructuralPartialEq for DelegationChainLink