pub struct Checkpoint {
pub origin: LogOrigin,
pub size: u64,
pub root: MerkleHash,
pub timestamp: DateTime<Utc>,
}Expand description
An unsigned transparency log checkpoint.
Args:
origin— Log origin string (e.g., “auths.dev/log”).size— Number of entries in the log at this checkpoint.root— Merkle root hash of the log at this size.timestamp— When the checkpoint was created.
Usage:
ⓘ
let cp = Checkpoint {
origin: LogOrigin::new("auths.dev/log")?,
size: 42,
root: merkle_root,
timestamp: Utc::now(),
};Fields
origin: LogOriginsize: u64root: MerkleHashtimestamp: DateTime<Utc>Implementations
Sourceimpl Checkpoint
impl Checkpoint
Sourcepub fn to_note_body(&self) -> String
pub fn to_note_body(&self) -> String
Serialize to the C2SP checkpoint body format (three lines: origin, size, base64 hash).
Sourcepub fn from_note_body(
body: &str,
timestamp: DateTime<Utc>,
) -> Result<Self, TransparencyError>
pub fn from_note_body( body: &str, timestamp: DateTime<Utc>, ) -> Result<Self, TransparencyError>
Parse from C2SP checkpoint body lines.