pub struct WitnessCosignature {
pub witness_name: String,
pub witness_public_key: Ed25519PublicKey,
pub signature: Ed25519Signature,
pub timestamp: DateTime<Utc>,
}Expand description
A witness cosignature on a checkpoint.
Witnesses independently verify the checkpoint and add their signature to increase trust in the log’s consistency claims.
Fields
witness_name: Stringwitness_public_key: Ed25519PublicKeysignature: Ed25519Signaturetimestamp: DateTime<Utc>Trait Implementations
Sourceimpl Clone for WitnessCosignature
impl Clone for WitnessCosignature
Sourcefn clone(&self) -> WitnessCosignature
fn clone(&self) -> WitnessCosignature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WitnessCosignature
impl Debug for WitnessCosignature
Sourceimpl<'de> Deserialize<'de> for WitnessCosignature
impl<'de> Deserialize<'de> for WitnessCosignature
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for WitnessCosignature
impl PartialEq for WitnessCosignature
Sourcefn eq(&self, other: &WitnessCosignature) -> bool
fn eq(&self, other: &WitnessCosignature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WitnessCosignature
impl Serialize for WitnessCosignature
impl StructuralPartialEq for WitnessCosignature