#[non_exhaustive]pub enum EntryBody {
Show 14 variants
Register {
inception_event: Value,
},
Rotate {
rotation_event: Value,
},
Abandon {
reason: Option<String>,
},
OrgCreate {
display_name: String,
},
OrgAddMember {
member_did: IdentityDID,
role: Role,
capabilities: Vec<Capability>,
delegated_by: IdentityDID,
},
OrgRevokeMember {
member_did: IdentityDID,
},
DeviceBind {
device_did: CanonicalDid,
public_key: Ed25519PublicKey,
},
DeviceRevoke {
device_did: CanonicalDid,
},
Attest(Value),
NamespaceClaim {
ecosystem: String,
package_name: String,
proof_url: String,
verification_method: String,
},
NamespaceDelegate {
ecosystem: String,
package_name: String,
delegate_did: IdentityDID,
},
NamespaceTransfer {
ecosystem: String,
package_name: String,
new_owner_did: IdentityDID,
},
AccessGrant {
subject_did: IdentityDID,
tier: AccessTier,
daily_limit: u32,
expires_at: DateTime<Utc>,
},
AccessRevoke {
subject_did: IdentityDID,
reason: Option<String>,
},
}Expand description
The body of a log entry, specific to each EntryType.
Designed so adding new entry types in future epics is a mechanical addition of a new variant.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Register
Rotate
Abandon
OrgCreate
OrgAddMember
OrgRevokeMember
Fields

member_did: IdentityDIDDeviceBind
DeviceRevoke
Fields

device_did: CanonicalDidAttest(Value)
NamespaceClaim
NamespaceDelegate
NamespaceTransfer
AccessGrant
AccessRevoke