pub struct EntryContent {
pub entry_type: EntryType,
pub body: EntryBody,
pub actor_did: CanonicalDid,
}Expand description
The subset of an Entry that the actor signs.
The sequencer assigns sequence and timestamp after — those fields
are authenticated by the Merkle tree, not the actor’s signature.
Usage:
ⓘ
let content = EntryContent {
entry_type: EntryType::Register,
body: EntryBody::Register { inception_event: serde_json::json!({}) },
actor_did: CanonicalDid::parse("did:keri:E...")?,
};
let canonical = content.canonicalize()?;Fields
entry_type: EntryTypebody: EntryBodyactor_did: CanonicalDidImplementations
Sourceimpl EntryContent
impl EntryContent
Sourcepub fn canonicalize(&self) -> Result<Vec<u8>, TransparencyError>
pub fn canonicalize(&self) -> Result<Vec<u8>, TransparencyError>
Canonical JSON bytes for signing (via json-canon).