pub struct InclusionProof {
pub index: u64,
pub size: u64,
pub root: MerkleHash,
pub hashes: Vec<MerkleHash>,
}Expand description
Merkle inclusion proof for a single entry in the log.
Proves that a leaf at index is included in the tree of size leaves
with the given root.
Args:
index— Zero-based leaf index.size— Tree size (number of leaves) when the proof was generated.root— Merkle root at tree sizesize.hashes— Sibling hashes from leaf to root.
Usage:
ⓘ
let proof = InclusionProof { index: 5, size: 16, root, hashes: vec![...] };
proof.verify(&leaf_hash)?;Fields
index: u64size: u64root: MerkleHashhashes: Vec<MerkleHash>Implementations
Sourceimpl InclusionProof
impl InclusionProof
Sourcepub fn verify(&self, leaf_hash: &MerkleHash) -> Result<(), TransparencyError>
pub fn verify(&self, leaf_hash: &MerkleHash) -> Result<(), TransparencyError>
Verify that leaf_hash is included in the tree.