pub struct ConsistencyProof {
pub old_size: u64,
pub new_size: u64,
pub old_root: MerkleHash,
pub new_root: MerkleHash,
pub hashes: Vec<MerkleHash>,
}Expand description
Merkle consistency proof between two tree sizes.
Proves that the tree at old_size is a prefix of the tree at new_size.
Args:
old_size— Earlier tree size.new_size— Later tree size.old_root— Root atold_size.new_root— Root atnew_size.hashes— Consistency proof hashes.
Usage:
ⓘ
let proof = ConsistencyProof { old_size: 8, new_size: 16, .. };
proof.verify()?;Fields
old_size: u64new_size: u64old_root: MerkleHashnew_root: MerkleHashhashes: Vec<MerkleHash>Implementations
Sourceimpl ConsistencyProof
impl ConsistencyProof
Sourcepub fn verify(&self) -> Result<(), TransparencyError>
pub fn verify(&self) -> Result<(), TransparencyError>
Verify that the old tree is a prefix of the new tree.